salary\_stone package
=====================

Submodules
----------

salary\_stone.salary\_extractor module
--------------------------------------

.. automodule:: salary_stone.salary_extractor
    :members:
    :undoc-members:
    :show-inheritance:

salary\_stone.skill\_extractor module
-------------------------------------

.. automodule:: salary_stone.skill_extractor
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: salary_stone
    :members:
    :undoc-members:
    :show-inheritance:
